#
# spec file for package weblug
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           weblug
Version:        0.5
Release:        1.6
Summary:        Simple webhook receiver program
License:        MIT
URL:            https://codeberg.org/grisu48/weblug
Source:         weblug-%{version}.tar.gz
Source1:        vendor.tar.gz
Source10:       weblug.yml
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.18
%{go_nostrip}
%{systemd_ordering}

%description
Simple webhook receiver program

%prep
%autosetup -D -a 1

%build
make all GOARGS="-mod vendor -buildmode pie"

%install
install -Dm 755 weblug %{buildroot}/%{_bindir}/weblug
# systemd unit
install -Dpm0644 weblug.service %{buildroot}%{_unitdir}/weblug.service
# configuration file (/etc/weblug.yml)
mkdir -p %{buildroot}%{_sysconfdir}
# use custom weblug config
cp -avL %{SOURCE10} weblug.yml
install -m 600 weblug.yml %{buildroot}%{_sysconfdir}/weblug.yml
# man page
install -Dm 644 doc/weblug.8 %{buildroot}/%{_mandir}/man8/weblug.8

%pre
%service_add_pre weblug.service

%preun
%service_del_preun weblug.service

%post
%service_add_post weblug.service

%postun
%service_del_postun weblug.service

%files
%doc README.md
%license LICENSE
%{_bindir}/weblug
%{_unitdir}/weblug.service
%config %{_sysconfdir}/weblug.yml
%{_mandir}/man8/weblug.8%{?ext_man}

%changelog
* Fri Apr  5 2024 felix.niederwanger@suse.com
- Update to version 0.5:
  * Add unit test for the message body and headers
  * Pass headers and body to subcommands
  * Add key generation section
  * Add note for reverse proxies
  * Update section
  * Remove self-signed TODO
  * Add TLS test
* Fri Aug  4 2023 Felix Niederwanger <felix.niederwanger@suse.com>
- Packaging improvements:
  * _service obs_scm enable changesgenerate
  * BuildRequires: golang(API) >= 1.18 instead of pinned go1.18
  * Reformat changelog entries per 'osc vc' template
* Fri Aug  4 2023 Felix Niederwanger <felix.niederwanger@suse.com>
- Add changesgenerate to service file
* Tue Jun  6 2023 Felix Niederwanger <felix.niederwanger@suse.com>
- Update to version 0.4
  * Add environment sanitation
  * Document caveats when running as root
  * Add possibility for dropping privileges
  * Add openSUSE specific configuration file that runs as 'nobody' by default (fixes bsc#1211197)
* Thu Apr 27 2023 Felix Niederwanger <felix.niederwanger@suse.com>
- Update to version 0.3
  * Add man page
* Thu Apr 27 2023 Felix Niederwanger <felix.niederwanger@suse.com>
- Fix the broken build for /etc/weblug.yml and the systemd unit
* Sat Apr 22 2023 Felix Niederwanger <felix.niederwanger@suse.com>
- Update to version 0.2
  * Adds feature to define an IP allow and blocked list per webhook
  * Adds systemd service unit
* Sun Mar  5 2023 Felix Niederwanger <felix.niederwanger@suse.com>
  * Kickoff - Version 0.1 (first Beta)
